@@ -29,7 +29,7 @@ __description__ = zfg.DESCRIPTION
 
 __version__ = zfg.VERSION
 
-__requires__ = zfg.REQUIRES.checked
+__requires__ = zfg.REQUIRES #.checked
 
 from .env import Environment
 # from .filters import filters
